@@ -41,7 +41,7 @@ class TestCloudfoundryClient(unittest.TestCase, AbstractTestCase, ):
              patch('cloudfoundry_client.client.requests', new=requests):
             requests.Session.return_value = session
             self._mock_info_calls(requests)
-            requests.post.return_value = MockResponse('%s/oauth/token' % self.TOKEN_ENDPOINT,
+            requests.post.return_value = MockResponse('%s/oauth/token' % self.AUTHORIZATION_ENDPOINT,
                                                       status_code=HTTPStatus.OK.value,
                                                       text=json.dumps(dict(access_token='access-token',
                                                                            refresh_token='refresh-token')))
@@ -65,7 +65,7 @@ class TestCloudfoundryClient(unittest.TestCase, AbstractTestCase, ):
              patch('cloudfoundry_client.client.requests', new=requests):
             requests.Session.return_value = session
             self._mock_info_calls(requests)
-            requests.post.return_value = MockResponse('%s/oauth/token' % self.TOKEN_ENDPOINT,
+            requests.post.return_value = MockResponse('%s/oauth/token' % self.AUTHORIZATION_ENDPOINT,
                                                       status_code=HTTPStatus.OK.value,
                                                       text=json.dumps(dict(access_token='access-token',
                                                                            refresh_token='refresh-token')))
@@ -88,7 +88,7 @@ class TestCloudfoundryClient(unittest.TestCase, AbstractTestCase, ):
              patch('cloudfoundry_client.client.requests', new=requests):
             requests.Session.return_value = session
             self._mock_info_calls(requests)
-            requests.post.return_value = MockResponse('%s/oauth/token' % self.TOKEN_ENDPOINT,
+            requests.post.return_value = MockResponse('%s/oauth/token' % self.AUTHORIZATION_ENDPOINT,
                                                       status_code=HTTPStatus.OK.value,
                                                       text=json.dumps(dict(access_token='access-token',
                                                                            refresh_token='refresh-token')))
@@ -118,3 +118,18 @@ class TestCloudfoundryClient(unittest.TestCase, AbstractTestCase, ):
             self.assertEqual(info.api_v2_version, self.API_V2_VERSION)
             self.assertEqual(info.doppler_endpoint, self.DOPPLER_ENDPOINT)
             self.assertEqual(info.log_stream_endpoint, self.LOG_STREAM_ENDPOINT)
+
+    def test_invalid_token_v3(self):
+        response = MockResponse('http://some-cf-url', 401, text=json.dumps(dict(
+            errors=[dict(code=666, title='Some-Error', detail='Error detail'),
+                    dict(code=1000, title='CF-InvalidAuthToken', detail='Invalid token')]
+        )))
+        result = CloudFoundryClient._is_token_expired(response)
+        self.assertTrue(result)
+
+    def test_invalid_token_v2(self):
+        response = MockResponse('http://some-cf-url', 401,
+                                text=json.dumps(dict(code=1000, error_code='CF-InvalidAuthToken')
+                                                ))
+        result = CloudFoundryClient._is_token_expired(response)
+        self.assertTrue(result)
